@@ -1,4 +1,4 @@
-context("roundtrip works")
+
 
 
 test_that("parse_tree_must_be_identical works", {
@@ -13,11 +13,13 @@ test_that("parse_tree_must_be_identical works", {
 })
 
 test_that("correct styling does not give an error", {
-  expect_error(verify_roundtrip("1+1", "1 + 1"), NA)
+  expect_snapshot({
+    verify_roundtrip("1+1", "1 + 1")
+  })
 })
 
 test_that("corrupt styling does give an error", {
-  expect_error(verify_roundtrip("1-1", "1 + 1"), "bug")
+  expect_snapshot_error(verify_roundtrip("1-1", "1 + 1"))
 })
 
 
